@@ -4,7 +4,6 @@
 # Python Imports
 import calendar
 import datetime
-import dateutil
 import decimal
 import functools
 import hashlib
@@ -21,6 +20,9 @@ import string
 import subprocess
 import xml
 
+# Extern Imports
+import dateutil.parser
+
 
 def absdir(path):
     return os.path.abspath(os.path.dirname(path))
